List of examples
~~~~~~~~~~~~~~~~

These pages are referenced by relative links in README.md.

.. toctree::
   :maxdepth: 0

   example1.md
   example2.md
   test_example2_py.md
   ../project
   setup.md
   test_setup_py.md
   setup_doctest.md
   test_setup_doctest_py.md
